@@ -31,11 +31,8 @@ release = "2023"
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = ["sphinxcontrib.mermaid", "sphinx_tabs.tabs", "autoapi.extension"]
+extensions = ["sphinxcontrib.mermaid", "sphinx_tabs.tabs", "sphinx.ext.napoleon", "sphinx_rtd_theme", "sphinx.ext.autodoc"]
 
-# Sphinx autoapi related
-autoapi_type = 'python'
-autoapi_dirs = ['../../flowrunner', '../../examples']
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
@@ -51,7 +48,7 @@ exclude_patterns = []
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 # Required theme setup
-html_theme = "sphinx_material"
+html_theme = "sphinx_rtd_theme"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -62,27 +59,4 @@ html_static_path = ["_static"]
 # Set link name generated in the top bar.
 html_title = "flowrunner"
 
-# Material theme options (see theme.conf for more information)
-html_theme_options = {
-    # Set the name of the project to appear in the navigation.
-    "nav_title": "flowrunner",
-    # Set you GA account ID to enable tracking
-    "google_analytics_account": "UA-XXXXX",
-    # Specify a base_url used to generate sitemap.xml. If not
-    # specified, then no sitemap will be built.
-    "base_url": "https://github.com/prithvijitguha/flowrunner",
-    # Set the color and the accent color
-    "color_primary": "indigo",
-    "color_accent": "orange",
-    # Set the repo location to get a badge with stats
-    "repo_url": "https://github.com/prithvijitguha/flowrunner",
-    "repo_name": "flowrunner",
-    # Visible levels of the global TOC; -1 means unlimited
-    "globaltoc_depth": 1,
-    # If False, expand all TOC entries
-    "globaltoc_collapse": False,
-    # If True, show hidden TOC entries
-    "globaltoc_includehidden": False,
-}
-
 html_sidebars = {"**": ["globaltoc.html"]}
