@@ -8,3 +8,10 @@ class InvalidFlowException(Exception):
     """Exception when there is an Invalid flow detected"""
 
     pass
+
+
+
+class CyclicFlowException(Exception):
+    """Exception when there is a Cyclic flow detected"""
+
+    pass
